#!/bin/bash

# Info:
#  Bash script that runs as ENTRYPOINT in the docker container "checkcode".
#  Used to run static code analysis on puppet code.
#
# Parameters:
#  Param 1: Which command to run, accepts "validate" or "parser".
#  Param 2: Array with .pp files that the command run against.
#
# Example:
#  Start container that runs 'puppet parser' on '$FILES':
#  $ docker run -v $(pwd):/root/puppet/ -t checkcode:latest parser "$FILES"
#
#  "$FILES" is created by the command:
#  $ FILES=$(git diff HEAD^ HEAD --name-only | grep '.pp')
#  This list all files with the 'pp' extension that has changed since last commit on the repo.


cd /root/puppet/

TYPE=$1; shift
ARRAY=($@)

# The command to run is chosen from the first parameter.
if [ "$TYPE" == "parser" ]; then
  echo "Running puppet parser validate"
  COMMAND="/opt/puppetlabs/bin/puppet parser validate"

elif [ "$TYPE" == "linter"  ]; then
  echo "Running puppet lint"
  COMMAND="/usr/bin/puppet-lint --no-autoloader_layout-check --fail-on-warnings --no-80chars-check --no-140chars-check"

else
  echo "Error: No parameter given in second position, must provide parser og linter"
  exit 1
fi

# Loops through all .pp files that have changed since last commit 
#  and runs the specified command on them.
for file in "${ARRAY[@]}"
do
  echo "$file"
  $COMMAND "$file"
done